bitcoinabuse_monitor
================

<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

-   Imports and formats bitcoinabuse.com data
-   Provides a statistical summary of the uploaded dataset
-   Provides a statistical distribution of the address size as bot
    activity increases.
-   Provides a dataframe of all addresses and an indication of whether
    it has duplication in its description or not
-   Provides a time range analysis on the range of spam of each
    individual addresses
-   Provides analytical insight on both the abuse type and the abusers

## Install

``` sh
pip install bitcoinabuse_monitor
```

## How to use

This package is simply utilised by first initialising an object then
applying useful functions as indicated in the analyzer page.
